@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: collect SA rule timings in redis
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 
 
 use Time::HiRes qw(time);
@@ -159,27 +159,28 @@ sub ran_rule {
     if( defined $exclude_re
             && $exclude_re ne ''
             &&  $name =~ /$exclude_re/ ) {
+        $permsg->{'rule_timing_start'} = Time::HiRes::time();
         return;
     }
     my $prefix = $self->{main}->{conf}->{'timing_redis_prefix'};
     my $precision = $self->{main}->{conf}->{'timing_redis_precision'};
 
     my $duration = int(($time - $permsg->{'rule_timing_start'}) * $precision);
-    $permsg->{'rule_timing_start'} = $time;
 
     my $redis = $self->_get_redis;
 
     if( $bulk )  {
         push( @$queue, [ $name, $duration ] );
 
-	if( scalar @$queue >= $bulk ) {
-		$self->_flush_queue( $queue );
-	}
+        if( scalar @$queue >= $bulk ) {
+            $self->_flush_queue( $queue );
+        }
     } else {
         $redis->incrby($prefix.$name.'.time', $duration, sub {} );
         $redis->incr($prefix.$name.'.count', sub {} );
     }
 
+    $permsg->{'rule_timing_start'} = Time::HiRes::time();
     return;
 }
 
@@ -221,7 +222,7 @@ Mail::SpamAssassin::Plugin::RuleTimingRedis - collect SA rule timings in redis
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 DESCRIPTION
 
